@@ -1,5 +1,5 @@
 from allauth.socialaccount.providers.oauth2.urls import default_urlpatterns
-from models import GitHubProvider
+from .provider import GitHubProvider
 
 urlpatterns = default_urlpatterns(GitHubProvider)
 
