@@ -1,4 +1,5 @@
 from allauth.socialaccount.providers.oauth.urls import default_urlpatterns
-from models import TwitterProvider
+
+from .provider import TwitterProvider
 
 urlpatterns = default_urlpatterns(TwitterProvider)
