@@ -1,23 +1,21 @@
-from django.utils import simplejson
+import json
 
 from allauth.socialaccount.providers.oauth.client import OAuth
 from allauth.socialaccount.providers.oauth.views import (OAuthAdapter,
                                                          OAuthLoginView,
-                                                         OAuthCallbackView,
-                                                         OAuthCompleteView)
+                                                         OAuthCallbackView)
 
-
-from models import TwitterProvider
+from .provider import TwitterProvider
 
 
 class TwitterAPI(OAuth):
     """
     Verifying twitter credentials
     """
-    url = 'https://twitter.com/account/verify_credentials.json'
+    url = 'https://api.twitter.com/1.1/account/verify_credentials.json'
 
     def get_user_info(self):
-        user = simplejson.loads(self.query(self.url))
+        user = json.loads(self.query(self.url))
         return user
 
 
@@ -29,18 +27,13 @@ class TwitterOAuthAdapter(OAuthAdapter):
     # authorize_url = 'https://api.twitter.com/oauth/authorize'
     authorize_url = 'https://api.twitter.com/oauth/authenticate'
 
-    def get_user_info(self, request, app):
-        client = TwitterAPI(request, app.key, app.secret,
+    def complete_login(self, request, app, token, response):
+        client = TwitterAPI(request, app.client_id, app.secret,
                             self.request_token_url)
-        user_info = client.get_user_info()
-        uid = user_info['id']
-        extra_data = { 'profile_image_url': user_info['profile_image_url'], 
-                       'screen_name': user_info['screen_name'] }
-        data = dict(twitter_user_info=user_info,
-                    username=user_info['screen_name'])
-        return uid, data, extra_data
+        extra_data = client.get_user_info()
+        return self.get_provider().sociallogin_from_response(request,
+                                                             extra_data)
 
 
 oauth_login = OAuthLoginView.adapter_view(TwitterOAuthAdapter)
 oauth_callback = OAuthCallbackView.adapter_view(TwitterOAuthAdapter)
-oauth_complete = OAuthCompleteView.adapter_view(TwitterOAuthAdapter)
