@@ -1,14 +1,18 @@
-from django.conf.urls.defaults import url, patterns, include
-from django.utils import importlib
+from django.conf.urls import url, patterns, include
+
+try:
+    import importlib
+except ImportError:
+    from django.utils import importlib
 
 from allauth.socialaccount import providers
 
-import app_settings
+from . import app_settings
 
 urlpatterns = patterns('', url('^', include('allauth.account.urls')))
 
 if app_settings.SOCIALACCOUNT_ENABLED:
-    urlpatterns += patterns('', url('^social/', 
+    urlpatterns += patterns('', url('^social/',
                                     include('allauth.socialaccount.urls')))
 
 for provider in providers.registry.get_list():
